@@ -6,7 +6,7 @@ from cloudsplaining.scan.policy_document import PolicyDocument
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.common.multi_signature import multi_signature
-from checkov.terraform.checks.utils.iam_cloudformation_document_to_policy_converter import \
+from checkov.cloudformation.checks.utils.iam_cloudformation_document_to_policy_converter import \
     convert_cloudformation_conf_to_iam_policy
 
 
@@ -30,7 +30,8 @@ class BaseCloudsplainingIAMCheck(BaseResourceCheck):
             # Scan all policies
             for policy in policy_conf:
                 policy_doc_key = 'PolicyDocument'
-                if policy_doc_key in policy.keys():
+                if isinstance(policy, dict) and policy_doc_key in policy.keys():
+                    # When using unresolved Cfn functions, policy is an str
                     policy_doc = policy[policy_doc_key]
                     try:
                         converted_policy_doc = convert_cloudformation_conf_to_iam_policy(policy_doc)
