@@ -3,15 +3,15 @@ from abc import ABC, abstractmethod
 
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 
+BC_API_URL = os.getenv('BC_API_URL', "https://www.bridgecrew.cloud/api/v1")
 
 class BaseIntegrationFeature(ABC):
-    bc_api_url = os.getenv('BC_API_URL', "https://www.bridgecrew.cloud/api/v1")
-    integrations_api_url = f"{bc_api_url}/integrations/types/checkov"
-    guidelines_api_url = f"{bc_api_url}/guidelines"
-    onboarding_url = f"{bc_api_url}/signup/checkov"
-    api_token_url = f"{bc_api_url}/integrations/apiToken"
-    suppressions_url = f"{bc_api_url}/suppressions"
-    fixes_url = f"{bc_api_url}/fixes/checkov"
+    integrations_api_url = f"{BC_API_URL}/integrations/types/checkov"
+    guidelines_api_url = f"{BC_API_URL}/guidelines"
+    onboarding_url = f"{BC_API_URL}/signup/checkov"
+    api_token_url = f"{BC_API_URL}/integrations/apiToken"
+    suppressions_url = f"{BC_API_URL}/suppressions"
+    fixes_url = f"{BC_API_URL}/fixes/checkov"
 
     def __init__(self, bc_integration, order):
         self.bc_integration = bc_integration
