@@ -5,7 +5,7 @@ import os
 import sys
 from abc import abstractmethod
 from itertools import chain
-from typing import Generator, Tuple
+from typing import Generator, Tuple, Dict, List, Optional, Any
 
 from checkov.common.checks.base_check import BaseCheck
 
@@ -19,17 +19,17 @@ class BaseCheckRegistry(object):
     #       checks aren't registered. (This happens with Serverless, for example.)
     __loading_external_checks = False
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.logger = logging.getLogger(__name__)
         # IMPLEMENTATION NOTE: Checks is used to directly access checks based on an specific entity
-        self.checks = defaultdict(list)
+        self.checks: Dict[str, List[BaseCheck]] = defaultdict(list)
         # IMPLEMENTATION NOTE: When using a wildcard, every pattern needs to be checked. To reduce the
         #                      number of checks checks with the same pattern are grouped, which is the
         #                      reason to use a dict for this too.
-        self.wildcard_checks = defaultdict(list)
-        self.check_id_allowlist = None
+        self.wildcard_checks: Dict[str, List[BaseCheck]] = defaultdict(list)
+        self.check_id_allowlist: Optional[List[str]] = None
 
-    def register(self, check):
+    def register(self, check: BaseCheck) -> None:
         # IMPLEMENTATION NOTE: Checks are registered when the script is loaded
         #                      (see BaseResourceCheck.__init__() for the various frameworks). The only
         #                      difficultly with this process is that external checks need to be specially
@@ -46,17 +46,14 @@ class BaseCheckRegistry(object):
                 checks[entity].append(check)
 
     @staticmethod
-    def _is_wildcard(entity):
-        return ('*' in entity
-                or '?' in entity
-                or ('[' in entity and ']' in entity))
+    def _is_wildcard(entity: str) -> bool:
+        return "*" in entity or "?" in entity or ("[" in entity and "]" in entity)
 
-    def get_check_by_id(self, check_id):
+    def get_check_by_id(self, check_id: str) -> Optional[BaseCheck]:
         return next(
-            filter(
-                lambda c: c.id == check_id,
-                chain(*self.checks.values(), *self.wildcard_checks.values())
-            ), None)
+            (check for check in chain(*self.checks.values(), *self.wildcard_checks.values()) if check.id == check_id),
+            None,
+        )
 
     def all_checks(self) -> Generator[Tuple[str, BaseCheck], None, None]:
         for entity, checks in self.checks.items():
@@ -70,7 +67,7 @@ class BaseCheckRegistry(object):
     def contains_wildcard(self) -> bool:
         return bool(self.wildcard_checks)
 
-    def get_checks(self, entity):
+    def get_checks(self, entity: str) -> List[BaseCheck]:
         if not self.wildcard_checks:
             # Optimisation: When no wildcards are used, we can use the list in self.checks
             return self.checks.get(entity) or []
@@ -82,19 +79,25 @@ class BaseCheckRegistry(object):
                     res += checks
             return res
 
-    def set_checks_allowlist(self, runner_filter):
+    def set_checks_allowlist(self, runner_filter: RunnerFilter) -> None:
         if runner_filter.checks:
             self.check_id_allowlist = runner_filter.checks
 
     @abstractmethod
-    def extract_entity_details(self, entity):
+    def extract_entity_details(self, entity: Dict[str, Any]) -> Tuple[str, str, Dict[str, Any]]:
         raise NotImplementedError()
 
-    def scan(self, scanned_file, entity, skipped_checks, runner_filter):
+    def scan(
+        self,
+        scanned_file: str,
+        entity: Dict[str, Any],
+        skipped_checks: List[Dict[str, str]],
+        runner_filter: RunnerFilter,
+    ) -> Dict[BaseCheck, Dict[str, Any]]:
 
         (entity_type, entity_name, entity_configuration) = self.extract_entity_details(entity)
 
-        results = {}
+        results: Dict[BaseCheck, Dict[str, Any]] = {}
 
         if not isinstance(entity_configuration, dict):
             return results
@@ -103,39 +106,48 @@ class BaseCheckRegistry(object):
         for check in checks:
             skip_info = {}
             if skipped_checks:
-                if check.id in [x['id'] for x in skipped_checks]:
-                    skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
+                if check.id in [x["id"] for x in skipped_checks]:
+                    skip_info = [x for x in skipped_checks if x["id"] == check.id][0]
 
             if runner_filter.should_run_check(check.id):
                 result = self.run_check(check, entity_configuration, entity_name, entity_type, scanned_file, skip_info)
                 results[check] = result
         return results
 
-    def run_check(self, check, entity_configuration, entity_name, entity_type, scanned_file, skip_info, tags=None):
+    def run_check(
+        self,
+        check: BaseCheck,
+        entity_configuration: Dict[str, List[Any]],
+        entity_name: str,
+        entity_type: str,
+        scanned_file: str,
+        skip_info: Dict[str, str],
+    ) -> Dict[str, Any]:
         self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
-        result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
-                           entity_name=entity_name, entity_type=entity_type, skip_info=skip_info)
+        result = check.run(
+            scanned_file=scanned_file,
+            entity_configuration=entity_configuration,
+            entity_name=entity_name,
+            entity_type=entity_type,
+            skip_info=skip_info,
+        )
         return result
 
     @staticmethod
-    def _directory_has_init_py(directory):
+    def _directory_has_init_py(directory: str) -> bool:
         """ Check if a given directory contains a file named __init__.py.
 
         __init__.py is needed to ensure the directory is a Python module, thus
         can be imported.
         """
-        if os.path.exists("{}/__init__.py".format(directory)):
-            return True
-        return False
+        return os.path.exists(f"{directory}/__init__.py")
 
     @staticmethod
-    def _file_can_be_imported(entry):
+    def _file_can_be_imported(entry: os.DirEntry) -> bool:
         """ Verify if a directory entry is a non-magic Python file."""
-        if entry.is_file() and not entry.name.startswith('__') and entry.name.endswith('.py'):
-            return True
-        return False
+        return entry.is_file() and not entry.name.startswith("__") and entry.name.endswith(".py")
 
-    def load_external_checks(self, directory):
+    def load_external_checks(self, directory: str) -> None:
         """ Browse a directory looking for .py files to import.
 
         Log an error when the directory does not contains an __init__.py or
@@ -151,7 +163,7 @@ class BaseCheckRegistry(object):
             else:
                 for entry in directory_content:
                     if self._file_can_be_imported(entry):
-                        check_name = entry.name.replace('.py', '')
+                        check_name = entry.name.replace(".py", "")
 
                         # Filter is set while loading external checks so the filter can be informed
                         # of the checks, which need to be handled specially.
@@ -162,13 +174,12 @@ class BaseCheckRegistry(object):
                         except SyntaxError as e:
                             self.logger.error(
                                 "Cannot load external check '{check_name}' from {check_full_path} : {error_message} ("
-                                "{error_line}:{error_column}) "
-                                    .format(
+                                "{error_line}:{error_column}) ".format(
                                     check_name=check_name,
                                     check_full_path=e.args[1][0],
                                     error_message=e.args[0],
                                     error_line=e.args[1][1],
-                                    error_column=e.args[1][2]
+                                    error_column=e.args[1][2],
                                 )
                             )
                         finally:
