@@ -14,7 +14,7 @@ class BaseRegistry:
         check_results = {}
         for check in self.checks:
             if runner_filter.checks and check.id not in runner_filter.checks \
-                    or runner_filter.skip_checks and check.id in runner_filter.skip_checks:
+                    or runner_filter.skip_checks and not runner_filter.should_run_check(check.id):
                 continue
             passed, failed = check.run(graph_connector)
             check_result = self._process_check_result(passed, [], CheckResult.PASSED)
