@@ -53,7 +53,7 @@ class Runner(BaseRunner):
         else: 
             lines = output.split('\n')
             for line in lines:
-                if line is not "":
+                if line != "":
                     if not "NAME" in line:
                         chart_name, chart_version, chart_repo, chart_status = line.split("\t")
                         chart_dependencies.update({chart_name.rstrip():{'chart_name': chart_name.rstrip(), 'chart_version': chart_version.rstrip(), 'chart_repo': chart_repo.rstrip(), 'chart_status': chart_status.rstrip()}})
