@@ -19,11 +19,11 @@ class ApiServerAdmissionControlAlwaysAdmit(BaseK8Check):
                     if cmd == "--enable-admission-plugins":
                         return CheckResult.FAILED
                     if "=" in cmd:
-                        [field,value] = cmd.split("=")
+                        [field,value,*_] = cmd.split("=")
                         if field == "--enable-admission-plugins":
                             if "AlwaysAdmit" == value:
                                 return CheckResult.FAILED
 
         return CheckResult.PASSED
 
-check = ApiServerAdmissionControlAlwaysAdmit()
\ No newline at end of file
+check = ApiServerAdmissionControlAlwaysAdmit()
