@@ -19,7 +19,7 @@ class ApiServerNodeRestrictionPlugin(BaseK8Check):
                     if cmd == "--enable-admission-plugins":
                         return CheckResult.FAILED  
                     if "=" in cmd:
-                        [field,value] = cmd.split("=")
+                        [field,value,*_] = cmd.split("=")
                         if field == "--enable-admission-plugins":
                             if "NodeRestriction" not in value:
                                 return CheckResult.FAILED                            
