@@ -14,7 +14,7 @@ class LivenessProbe(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         # Don't check Job/CronJob
@@ -25,4 +25,5 @@ class LivenessProbe(BaseK8Check):
             return CheckResult.FAILED
         return CheckResult.PASSED
 
-check = LivenessProbe()
\ No newline at end of file
+
+check = LivenessProbe()
