@@ -19,7 +19,7 @@ class SchedulerBindAddress(BaseK8Check):
             if "kube-scheduler" in conf["command"]:
                 for cmd in conf["command"]:
                     if "=" in cmd:
-                        [key, value] = cmd.split("=")
+                        [key, value, *_] = cmd.split("=")
                         if key == "--bind-address" and value == "127.0.0.1":
                             return CheckResult.PASSED
                 return CheckResult.FAILED
