@@ -10,6 +10,7 @@ from pathlib import Path
 from checkov.arm.runner import Runner as arm_runner
 from checkov.cloudformation.runner import Runner as cfn_runner
 from checkov.common.bridgecrew.platform_integration import bc_integration
+from checkov.common.bridgecrew.image_scanning.image_scanner import image_scanner
 from checkov.common.goget.github.get_git import GitGetter
 from checkov.common.runners.runner_registry import RunnerRegistry, OUTPUT_CHOICES
 from checkov.common.util.banner import banner as checkov_banner
@@ -64,7 +65,12 @@ def run(banner=checkov_banner, argv=sys.argv[1:]):
     if args.version:
         print(version)
         return
-    if args.bc_api_key:
+
+    if args.bc_api_key == '':
+        parser.error('The --bc-api-key flag was specified but the value was blank. If this value was passed as a secret, you may need to double check the mapping.')
+    elif args.bc_api_key:
+        logger.debug(f'Using API key ending with {args.bc_api_key[-8:]}')
+
         if args.repo_id is None:
             parser.error("--repo-id argument is required when using --bc-api-key")
         if len(args.repo_id.split('/')) != 2:
@@ -75,13 +81,15 @@ def run(banner=checkov_banner, argv=sys.argv[1:]):
         source_version = os.getenv('BC_SOURCE_VERSION', version)
         logger.debug(f'BC_SOURCE = {source}, version = {source_version}')
         try:
-            bc_integration.setup_bridgecrew_credentials(bc_api_key=args.bc_api_key, repo_id=args.repo_id,
+            bc_integration.setup_bridgecrew_credentials(bc_api_key=args.bc_api_key, repo_id=args.repo_id, 
                                                         skip_fixes=args.skip_fixes,
                                                         skip_suppressions=args.skip_suppressions,
-                                                        source=source, source_version=source_version)
+                                                        source=source, source_version=source_version, repo_branch=args.branch)
         except Exception as e:
             logger.error('An error occurred setting up the Bridgecrew platform integration. Please check your API token and try again.', exc_info=True)
             return
+    else:
+        logger.debug('No API key found. Scanning locally only.')
 
     guidelines = {}
     if not args.no_guide:
@@ -120,6 +128,17 @@ def run(banner=checkov_banner, argv=sys.argv[1:]):
             bc_integration.persist_scan_results(scan_reports)
             url = bc_integration.commit_repository(args.branch)
         return runner_registry.print_reports(scan_reports, args, url)
+    elif args.docker_image:
+        if args.bc_api_key is None:
+            parser.error("--bc-api-key argument is required when using --docker-image")
+            return
+        if args.dockerfile_path is None:
+            parser.error("--dockerfile-path argument is required when using --docker-image")
+            return
+        if args.branch is None:
+            parser.error("--branch argument is required when using --docker-image")
+            return
+        image_scanner.scan(args.docker_image, args.dockerfile_path)
     else:
         print(f"{banner}")
 
@@ -167,6 +186,8 @@ def add_parser_args(parser):
     parser.add_argument('-s', '--soft-fail',
                         help='Runs checks but suppresses error code', action='store_true')
     parser.add_argument('--bc-api-key', help='Bridgecrew API key')
+    parser.add_argument('--docker-image', help='Scan docker images by name or ID. Only works with --bc-api-key flag')
+    parser.add_argument('--dockerfile-path', help='Path to the Dockerfile of the scanned docker image')
     parser.add_argument('--repo-id',
                         help='Identity string of the repository, with form <repo_owner>/<repo_name>')
     parser.add_argument('-b', '--branch',
