@@ -1,4 +1,7 @@
+import logging
 import fnmatch
+from typing import Set, Optional, Union, List
+
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
 
 
@@ -6,9 +9,19 @@ class RunnerFilter(object):
     # NOTE: This needs to be static because different filters may be used at load time versus runtime
     #       (see note in BaseCheckRegistery.register). The concept of which checks are external is
     #       logically a "static" concept anyway, so this makes logical sense.
-    __EXTERNAL_CHECK_IDS = set()
+    __EXTERNAL_CHECK_IDS: Set[str] = set()
 
-    def __init__(self, framework='all', checks=None, skip_checks=None, download_external_modules=False, external_modules_download_path=DEFAULT_EXTERNAL_MODULES_DIR, evaluate_variables=True):
+    def __init__(
+        self,
+        framework: str = "all",
+        checks: Union[str, List[str], None] = None,
+        skip_checks: Union[str, List[str], None] = None,
+        download_external_modules: bool = False,
+        external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR,
+        evaluate_variables: bool = True,
+        runners: Optional[List[str]] = None,
+        skip_framework: Optional[str] = None,
+    ) -> None:
         if checks is None:
             checks = []
         if isinstance(checks, str):
@@ -22,14 +35,29 @@ class RunnerFilter(object):
             self.skip_checks = skip_checks.split(",")
         else:
             self.skip_checks = skip_checks
-        self.framework = framework
+
+        if skip_framework is None:
+            self.framework = framework
+        else:
+            if isinstance(skip_framework, str):
+                if framework == "all":
+                    if runners is None:
+                        runners = []
+
+                    selected_frameworks = list(set(runners) - set(skip_framework.split(",")))
+                    self.framework = ",".join(selected_frameworks)
+                else:
+                    selected_frameworks = list(set(framework.split(",")) - set(skip_framework.split(",")))
+                    self.framework = ",".join(selected_frameworks)
+        logging.info(f"Resultant set of frameworks (removing skipped frameworks): {self.framework}")
+
         self.download_external_modules = download_external_modules
         self.external_modules_download_path = external_modules_download_path
         self.evaluate_variables = evaluate_variables
 
-    def should_run_check(self, check_id):
+    def should_run_check(self, check_id: str) -> bool:
         if RunnerFilter.is_external_check(check_id):
-            pass        # enabled unless skipped
+            pass  # enabled unless skipped
         elif self.checks:
             if check_id in self.checks:
                 return True
@@ -40,9 +68,9 @@ class RunnerFilter(object):
         return True
 
     @staticmethod
-    def notify_external_check(check_id):
+    def notify_external_check(check_id: str) -> None:
         RunnerFilter.__EXTERNAL_CHECK_IDS.add(check_id)
 
     @staticmethod
-    def is_external_check(check_id):
+    def is_external_check(check_id: str) -> bool:
         return check_id in RunnerFilter.__EXTERNAL_CHECK_IDS
