@@ -4,10 +4,10 @@ from checkov.terraform.checks.resource.base_resource_value_check import BaseReso
 
 class DynamoDBTablesEncrypted(BaseResourceValueCheck):
     def __init__(self):
-        name = "Ensure DynamoDB Tables are encrypted"
+        name = "Ensure DynamoDB Tables are encrypted using KMS"
         id = "CKV_AWS_119"
-        supported_resources = ['aws_dynamodb_table']
-        categories = [CheckCategories.NETWORKING]
+        supported_resources = ["aws_dynamodb_table"]
+        categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def get_inspected_key(self):
