@@ -16,12 +16,12 @@ class IAMStarActionPolicyDocument(BaseResourceCheck):
     def scan_resource_conf(self, conf):
         if 'policy' in conf.keys():
             try:
-                policy_block = json.loads(conf['policy'][0])
+                policy_block = conf['policy'][0]
                 if 'Statement' in policy_block.keys():
                     for statement in force_list(policy_block['Statement']):
                         if 'Action' in statement and \
                                 statement.get('Effect', ['Allow']) == 'Allow' and \
-                                '*' in statement.get('Action', ['']):
+                                '*' in force_list(statement['Action']):
                             return CheckResult.FAILED
             except: # nosec
                 pass
