@@ -1,6 +1,6 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.util.secrets import string_has_secrets, AWS
+from checkov.common.util.secrets import string_has_secrets, AWS, GENERAL
 from checkov.common.util.type_forcers import force_list
 
 
@@ -22,7 +22,7 @@ class LambdaEnvironmentCredentials(BaseResourceCheck):
                         # variables can be a string, which in this case it points to a variable
                         for values in list(force_list(conf['environment'][0]['variables'])[0].values()):
                             for value in list(filter(lambda value: isinstance(value, str), force_list(values))):
-                                if string_has_secrets(value):
+                                if string_has_secrets(value,AWS,GENERAL):
                                     return CheckResult.FAILED
         return CheckResult.PASSED
 
