@@ -1,6 +1,5 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck
-import re
 
 
 class CustomRoleDefinitionSubscriptionOwner(BaseResourceCheck):
@@ -12,10 +11,8 @@ class CustomRoleDefinitionSubscriptionOwner(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        subscription = re.compile(r"\/|\/subscriptions\/[\w\d-]+$|\${(data|resource)\.azurerm_subscription\.")
-        if any(re.match(subscription, scope) for scope in conf['assignable_scopes'][0]):
-            if 'actions' in conf['permissions'][0] and '*' in conf['permissions'][0]['actions'][0]:
-                return CheckResult.FAILED
+        if 'actions' in conf['permissions'][0] and '*' in conf['permissions'][0]['actions'][0]:
+            return CheckResult.FAILED
         return CheckResult.PASSED
 
 
