@@ -1,13 +1,13 @@
+from typing import Dict, Any, Tuple
+
 from checkov.common.checks.base_check_registry import BaseCheckRegistry
-from checkov.terraform.tag_providers import get_resource_tags
 
 
 class Registry(BaseCheckRegistry):
-
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
 
-    def extract_entity_details(self, entity):
+    def extract_entity_details(self, entity: Dict[str, Any]) -> Tuple[str, str, Dict[str, Any]]:
         resource_type = list(entity.keys())[0]
         resource_name = list(list(entity.values())[0].keys())[0]
         resource_object = entity[resource_type]
