@@ -2,6 +2,8 @@ import logging
 import re
 from abc import ABC, abstractmethod
 from itertools import islice
+from pathlib import Path
+from typing import List, Dict, Any, Tuple, Optional
 
 import dpath.util
 
@@ -10,18 +12,20 @@ from checkov.common.models.enums import ContextCategories
 from checkov.terraform.context_parsers.registry import parser_registry
 from checkov.common.bridgecrew.platform_integration import bc_integration
 
-OPEN_CURLY = '{'
-CLOSE_CURLY = '}'
+OPEN_CURLY = "{"
+CLOSE_CURLY = "}"
 
 
 class BaseContextParser(ABC):
     definition_type = ""
     tf_file = ""
-    file_lines = []
-    context = {}
+    tf_file_path: Optional[Path] = None
+    file_lines: List[Tuple[int, str]] = []
+    filtered_lines: List[Tuple[int, str]] = []
+    context: Dict[str, Any] = {}
 
-    def __init__(self, definition_type):
-        #bc_integration.setup_http_manager()
+    def __init__(self, definition_type: str) -> None:
+        # bc_integration.setup_http_manager()
         self.logger = logging.getLogger("{}".format(self.__module__))
         if definition_type.upper() not in ContextCategories.__members__:
             self.logger.error("Terraform context parser type not supported yet")
@@ -30,7 +34,7 @@ class BaseContextParser(ABC):
         parser_registry.register(self)
 
     @abstractmethod
-    def get_entity_context_path(self, entity_block):
+    def get_entity_context_path(self, entity_block: Dict[str, Dict[str, Any]]) -> List[str]:
         """
         returns the entity's path in the context parser
         :param entity_block: entity definition block
@@ -38,7 +42,7 @@ class BaseContextParser(ABC):
         """
         raise NotImplementedError
 
-    def _is_block_signature(self, line_num, line_tokens, entity_context_path):
+    def _is_block_signature(self, line_num: int, line_tokens: List[str], entity_context_path: List[str]) -> bool:
         """
         Determine if the given tokenized line token is the entity signature line
         :param line_num: The line number in the file
@@ -50,22 +54,21 @@ class BaseContextParser(ABC):
         return all(x in line_tokens for x in [block_type] + entity_context_path)
 
     @staticmethod
-    def _trim_whitespaces_linebreaks(text):
+    def _trim_whitespaces_linebreaks(text: str) -> str:
         return text.strip()
 
-    def _filter_file_lines(self):
+    def _filter_file_lines(self) -> List[Tuple[int, str]]:
         parsed_file_lines = [(ind, self._trim_whitespaces_linebreaks(line)) for (ind, line) in self.file_lines]
         self.filtered_lines = [(ind, line) for (ind, line) in parsed_file_lines if line]
         return self.filtered_lines
 
-    def _read_file_lines(self):
-        with(open(self.tf_file, 'r')) as file:
+    def _read_file_lines(self) -> List[Tuple[int, str]]:
+        with (open(self.tf_file, "r")) as file:
             file.seek(0)
-            file_lines = [(ind + 1, line) for (ind, line) in
-                          list(enumerate(file.readlines()))]
+            file_lines = [(ind + 1, line) for (ind, line) in list(enumerate(file.readlines()))]
             return file_lines
 
-    def _collect_skip_comments(self, definition_blocks):
+    def _collect_skip_comments(self, definition_blocks: List[Dict[str, Any]]) -> Dict[str, Any]:
         """
         Collects checkov skip comments to all definition blocks
         :param definition_blocks: parsed definition blocks
@@ -73,25 +76,32 @@ class BaseContextParser(ABC):
         """
         bc_id_mapping = bc_integration.get_id_mapping()
         parsed_file_lines = self.filtered_lines
-        comments = [(line_num, {"id": re.search(COMMENT_REGEX, x).group(2),
-                                "suppress_comment": re.search(COMMENT_REGEX, x).group(3)[1:] if re.search(COMMENT_REGEX,
-                                                                                                          x).group(3)
-                                else "No comment provided"}) for (line_num, x) in
-                    parsed_file_lines if re.search(COMMENT_REGEX, x)]
+        comments = [
+            (
+                line_num,
+                {
+                    "id": match.group(2),
+                    "suppress_comment": match.group(3)[1:] if match.group(3) else "No comment provided",
+                },
+            )
+            for (line_num, x) in parsed_file_lines
+            for match in [re.search(COMMENT_REGEX, x)]
+            if match
+        ]
         for entity_block in definition_blocks:
             skipped_checks = []
             entity_context_path = self.get_entity_context_path(entity_block)
             context_search = dpath.search(self.context, entity_context_path, yielded=True)
             for _, entity_context in context_search:
                 for (skip_check_line_num, skip_check) in comments:
-                    if entity_context['start_line'] < skip_check_line_num < entity_context['end_line']:
-                        if bc_id_mapping and skip_check['id'] in bc_id_mapping:
-                            skip_check['id'] = bc_id_mapping[skip_check['id']]
+                    if entity_context["start_line"] < skip_check_line_num < entity_context["end_line"]:
+                        if bc_id_mapping and skip_check["id"] in bc_id_mapping:
+                            skip_check["id"] = bc_id_mapping[skip_check["id"]]
                         skipped_checks.append(skip_check)
-            dpath.new(self.context, entity_context_path + ['skipped_checks'], skipped_checks)
+            dpath.new(self.context, entity_context_path + ["skipped_checks"], skipped_checks)
         return self.context
 
-    def _compute_definition_end_line(self, start_line_num):
+    def _compute_definition_end_line(self, start_line_num: int) -> int:
         """ Given the code block's start line, compute the block's end line
         :param start_line_num: code block's first line number (the signature line)
         :return: the code block's last line number
@@ -110,13 +120,17 @@ class BaseContextParser(ABC):
                     break
         return end_line_num
 
-    def run(self, tf_file, definition_blocks, collect_skip_comments=True):
+    def run(
+        self, tf_file: str, definition_blocks: List[Dict[str, Any]], collect_skip_comments: bool = True
+    ) -> Dict[str, Any]:
         # TF files for loaded modules have this formation:  <file>[<referrer>#<index>]
         # Chop off everything after the file name for our purposes here
         if tf_file.endswith("]") and "[" in tf_file:
-            self.tf_file = tf_file[:tf_file.index("[")]
+            self.tf_file = tf_file[: tf_file.index("[")]
+            self.tf_file_path = Path(tf_file[: tf_file.index("[")])
         else:
             self.tf_file = tf_file
+            self.tf_file_path = Path(tf_file)
         self.context = {}
         self.file_lines = self._read_file_lines()
         self.context = self.enrich_definition_block(definition_blocks)
@@ -124,17 +138,19 @@ class BaseContextParser(ABC):
             self.context = self._collect_skip_comments(definition_blocks)
         return self.context
 
-    def get_block_type(self):
+    def get_block_type(self) -> str:
         return self.definition_type
 
-    def enrich_definition_block(self, definition_blocks):
+    def enrich_definition_block(self, definition_blocks: List[Dict[str, Any]]) -> Dict[str, Any]:
         """
         Enrich the context of a Terraform block
         :param definition_blocks: Terraform block, key-value dictionary
         :return: Enriched block context
         """
         parsed_file_lines = self._filter_file_lines()
-        potential_block_start_lines = [(ind, line) for (ind, line) in parsed_file_lines if line.startswith(self.get_block_type())]
+        potential_block_start_lines = [
+            (ind, line) for (ind, line) in parsed_file_lines if line.startswith(self.get_block_type())
+        ]
         for i, entity_block in enumerate(definition_blocks):
             entity_context_path = self.get_entity_context_path(entity_block)
             for line_num, line in potential_block_start_lines:
@@ -145,8 +161,9 @@ class BaseContextParser(ABC):
                     end_line = self._compute_definition_end_line(line_num)
                     dpath.new(self.context, entity_context_path + ["start_line"], start_line)
                     dpath.new(self.context, entity_context_path + ["end_line"], end_line)
-                    dpath.new(self.context, entity_context_path + ["code_lines"],
-                              self.file_lines[start_line - 1: end_line])
+                    dpath.new(
+                        self.context, entity_context_path + ["code_lines"], self.file_lines[start_line - 1 : end_line]
+                    )
                     potential_block_start_lines.remove((line_num, line))
                     break
         return self.context
